<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<!-- XSL Rule file to transform extracted Data from R/3 to WCS -->

<!-- Variable Name Definations Section Starts -->
  <xsl:param name="ImportLocation" select="'import.dtd'"/>   
  <xsl:variable name="RootElement">import</xsl:variable> 
  <xsl:variable name="VersionElement">V5.1</xsl:variable> 
  <xsl:variable name="RootPrefix">@</xsl:variable>
  <xsl:variable name="RecordSeperator">&#13;</xsl:variable>   
  
  <xsl:variable name="attrtypeid">STRING</xsl:variable>
  <xsl:variable name="CatentryRelationType">PRODUCT_ITEM</xsl:variable>
  <xsl:variable name="CatentryItemType">ItemBean</xsl:variable>
  <xsl:variable name="CatentryProductType">ProductBean</xsl:variable>
  <xsl:variable name="BaseItemType">ITEM</xsl:variable>
  <xsl:variable name="HundredValue">100</xsl:variable>
  <xsl:variable name="FalseFlag">N</xsl:variable>
  <xsl:variable name="TrueFlag">Y</xsl:variable>
  <xsl:variable name="ZeroValue">0</xsl:variable>
  <xsl:variable name="OneValue">1</xsl:variable>

  
  <xsl:variable name="Englishid">en_US</xsl:variable>
  <xsl:variable name="Germanid">de_DE</xsl:variable>
  <xsl:variable name="Chineseid">zh_CN</xsl:variable>
  <xsl:variable name="Thaiid">zh_TW</xsl:variable>
  <xsl:variable name="Koreanid">ko_KR</xsl:variable>
  <xsl:variable name="Frenchid">fr_FR</xsl:variable>
  <xsl:variable name="Italianid">it_IT</xsl:variable>
  <xsl:variable name="Japaneseid">ja_JP</xsl:variable>
  <xsl:variable name="Portugueseid">pt_BR</xsl:variable>
  <xsl:variable name="Spanishid">es_ES</xsl:variable>

  <!-- Varibale to construct default Product description and Name -->
  <xsl:variable name="DefaultProductDesc">Product - </xsl:variable>


  <xsl:param name="DefaultCatgroupIdentifier" select="'SAP Products'"/>
  <xsl:param name="DefaultSubCatgroupIdentifier" select="'SAP Category 1'"/>
  <xsl:param name="DefaultSubCatgroupDescription" select="'SAP Drill bits'"/>
  <xsl:param name="DefaultProductPartNumber" select="'SAP10001'"/>
  <xsl:param name="DefaultProductMFPartNumber" select="'SAP-Tools-10001'"/>
  <xsl:param name="DefaultProductMFName" select="'SAP Tools'"/>


  <xsl:param name="StoreIdentifier" select="10551"/>
  <xsl:param name="MemberIdentifier" select="-20001"/>   
  <xsl:param name="TradingPositionName" select="'ToolTech1'"/>  
  <xsl:param name="CatalogName" select="'ToolTech1'"/>   
  <xsl:param name="FullFillmentCenterName" select="'ToolTech'"/>


  <!-- Variable Name Definitions Section Ends -->

  <!-- Transformation Rules Section Starts -->
<xsl:template match="/"> 
<xsl:text disable-output-escaping = "yes">&lt;!DOCTYPE import SYSTEM "</xsl:text> 
<xsl:value-of select = "$ImportLocation"/> 
<xsl:text disable-output-escaping = "yes">"&gt;&#13;</xsl:text> 
<xsl:element name="{$RootElement}">

	<xsl:call-template name="CreateDefaultCatgroup"/>
	<xsl:call-template name="CreateDefaultCatgroupDesc"/>
	<xsl:call-template name="CreateDefaultSubCatgroup"/>
	<xsl:call-template name="CreateDefaultSubCatgroupDesc"/>
	<xsl:call-template name="CreateStoreGroup"/>
	<xsl:call-template name="CreateSubStoreGroup"/>
	<xsl:call-template name="CreateCatalogToGroup"/>
	<xsl:call-template name="CreateSubCategoryToCategory"/>

	<xsl:for-each select=".//qtyunit">
		<xsl:call-template name="Copyqtyunit"/>
	</xsl:for-each> 
	<xsl:for-each select=".//baseitem">
		 <xsl:call-template name="BaseItem"/>
	</xsl:for-each>
	<xsl:for-each select=".//itemspc">
		 <xsl:call-template name="ItemSpc"/>
	</xsl:for-each>
	<xsl:for-each select=".//catentry">
		 <xsl:call-template name="Create"/>
	</xsl:for-each>
	<xsl:for-each select=".//parentcatentry">

<!--Only if the material is associated to a material group, is an entry made 
	in CATENTRY for this material group -->
	  <xsl:if test="@partnumber!=''">
		 <xsl:call-template name="CreateParent"/>
	  </xsl:if>
	</xsl:for-each>
	<xsl:for-each select=".//catgpenrel">
		 <xsl:call-template name="CreateCatGroupRel"/>
	</xsl:for-each>
	<xsl:for-each select=".//storecent">
		 <xsl:call-template name="StoreCatentryRel"/>
	</xsl:for-each>
	<xsl:for-each select=".//parentstorecent">
		 <xsl:call-template name="ParentStoreCatentryRel"/>
	</xsl:for-each>
	<xsl:for-each select=".//catentdesc">
		<xsl:call-template name="Createindesc"/>
	</xsl:for-each> 
<!--Only if the material is associated to a material group, is an entry made 
	in CATENTDESC for this material group -->
	<xsl:for-each select=".//parentcatentdesc">
	  <xsl:if test="@catentry_id!=''">
		<xsl:call-template name="CreateParentindesc"/>
	  </xsl:if>
	</xsl:for-each> 
	<xsl:for-each select=".//listprice">
		<xsl:call-template name="Createinprice"/>
	</xsl:for-each> 
	<xsl:for-each select=".//catentship">
		<xsl:call-template name="Createinship"/>
	</xsl:for-each> 
	<xsl:for-each select=".//catentrel">
		<xsl:call-template name="Copycatentrel"/>
	</xsl:for-each> 
	<xsl:for-each select=".//attribute">
		<xsl:call-template name="Copyattr"/>
	</xsl:for-each> 
	<xsl:for-each select=".//attrvalue">
		<xsl:call-template name="Copyattrval"/>
	</xsl:for-each> 
	<xsl:for-each select=".//offer">
		<xsl:call-template name="Copyoffer"/>
	</xsl:for-each> 
	<xsl:for-each select=".//offerprice">
		<xsl:call-template name="Copyofferprice"/>
	</xsl:for-each> 
	<xsl:for-each select=".//inventory">
		<xsl:if test="@indicator='I'">
			<xsl:call-template name="Copyinventory"/>
		</xsl:if>
	</xsl:for-each> 
	<xsl:for-each select=".//storeitem">
		<xsl:call-template name="Copystoreitem"/>
	</xsl:for-each>

</xsl:element>	

</xsl:template>


<!-- Transformation Rules Section Ends -->

<!-- Transformation Rules for category in CATGROUP starts -->

<xsl:template name="CreateDefaultCatgroup">   
	<xsl:element name="catgroup">      
              <xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="member_id">
			<xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="identifier">
			<xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for CATGROUP ends -->

<!-- Transformation Rules for description of category in CATGRPDESC starts -->

<xsl:template name="CreateDefaultCatgroupDesc">   
	<xsl:element name="catgrpdesc">      
              <xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="name">
			<xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="shortdescription">
			<xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="longdescription">
			<xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="language_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$Englishid"/>
              </xsl:attribute>
		  <xsl:attribute name="published">
	                  <xsl:value-of select="$OneValue"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for description of CATGROUP ends -->


<!-- Transformation Rules for sub-category in CATGROUP starts -->

<xsl:template name="CreateDefaultSubCatgroup">   
	<xsl:element name="catgroup">      
              <xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="member_id">
			<xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="identifier">
			<xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for sub-category in CATGROUP ends -->

<!-- Transformation Rules for description of sub category in CATGRPDESC starts -->

<xsl:template name="CreateDefaultSubCatgroupDesc">   
	<xsl:element name="catgrpdesc">
              <xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="name">
			<xsl:value-of select="$DefaultSubCatgroupDescription"/>
              </xsl:attribute>
		  <xsl:attribute name="shortdescription">
			<xsl:value-of select="$DefaultSubCatgroupDescription"/>
              </xsl:attribute>
		  <xsl:attribute name="longdescription">
			<xsl:value-of select="$DefaultSubCatgroupDescription"/>
              </xsl:attribute>
		  <xsl:attribute name="language_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$Englishid"/>
              </xsl:attribute>
		  <xsl:attribute name="published">
	                  <xsl:value-of select="$OneValue"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for description of  SUB CATGROUP ends -->


<!-- Transformation Rules for category in STORECGRP starts -->

<xsl:template name="CreateStoreGroup">   
	<xsl:element name="storecgrp">      
      	<xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	      	<xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultCatgroupIdentifier"/>
            </xsl:attribute>
		<xsl:attribute name="storeent_id">
                  <xsl:value-of select="$StoreIdentifier"/>
            </xsl:attribute>
      </xsl:element> 
</xsl:template>

<!-- Transformation Rules for category in STORECGRP ends -->

<!-- Transformation Rules for sub-category in STORECGRP starts -->

<xsl:template name="CreateSubStoreGroup">   
	<xsl:element name="storecgrp">      
      	<xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	      	<xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
            </xsl:attribute>
		<xsl:attribute name="storeent_id">
                  <xsl:value-of select="$StoreIdentifier"/>
            </xsl:attribute>
      </xsl:element> 
</xsl:template>

<!-- Transformation Rules for sub-category in STORECGRP ends -->

<!-- Transformation Rules for relating catalog to category in CATTOGRP starts -->

<xsl:template name="CreateCatalogToGroup">   
	<xsl:element name="cattogrp">      
      	<xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
		   <xsl:attribute name="catalog_id">
				<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
				<xsl:value-of select="$RootPrefix"/>
				<xsl:value-of select="$CatalogName"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for relating catalog to category in CATTOGRP ends -->

<!-- Transformation Rules for relating category to sub-category in CATGRPREL starts -->

<xsl:template name="CreateSubCategoryToCategory">   
	<xsl:element name="catgrprel">      
      	<xsl:attribute name="catgroup_id_parent">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultCatgroupIdentifier"/>
              </xsl:attribute>
      	<xsl:attribute name="catgroup_id_child">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
            </xsl:attribute>
 	      <xsl:attribute name="catalog_id">
				<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
				<xsl:value-of select="$RootPrefix"/>
				<xsl:value-of select="$CatalogName"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for relating category to sub-category in CATGRPREL ends -->

<!-- Transformation Rules for relating item to store in STORECENT starts -->

<xsl:template name="StoreCatentryRel">   
	<xsl:element name="storecent">      
              <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@catentry_id"/>
              </xsl:attribute>
		   <xsl:attribute name="storeent_id">
                  <xsl:value-of select="$StoreIdentifier"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for relating item to store in STORECENT ends -->

<!-- Transformation Rules for relating product to store in STORECENT starts -->

<xsl:template name="ParentStoreCatentryRel">   
	<xsl:element name="storecent">      
              <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@catentry_id)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@catentry_id)"/>
				</xsl:otherwise>
			</xsl:choose>
               </xsl:attribute>
		   <xsl:attribute name="storeent_id">
                  <xsl:value-of select="$StoreIdentifier"/>
              </xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for relating product to store in STORECENT ends -->

<!-- Transformation Rules for creating a baseitem for a product in BASEITEM starts -->

<xsl:template name="BaseItem">   
	<xsl:element name="baseitem">      
              <xsl:attribute name="baseitem_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@partnumber"/>
				</xsl:otherwise>
			</xsl:choose>

              </xsl:attribute>
		   <xsl:attribute name="itemtype_id">
	                  <xsl:value-of select="$BaseItemType"/>
              </xsl:attribute>
		  <xsl:attribute name="member_id">
	                  <xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
		  <xsl:attribute name="quantitymultiple">
	                  <xsl:value-of select="$OneValue"/>
              </xsl:attribute>
		  <xsl:attribute name="lastupdate">
			<xsl:if test="@lastupdate!='00000000'">
	                  <xsl:value-of select="@lastupdate "/>
			</xsl:if>
              </xsl:attribute>
		  <xsl:attribute name="partnumber">
		  	<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>


		<xsl:copy-of select="@quantitymeasure"/>

     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for creating a baseitem for a product in BASEITEM ends -->

<!-- Transformation Rules for creating a itemspc for an item in ITEMSPC starts -->

<xsl:template name="ItemSpc">   
	<xsl:element name="itemspc">      
              <xsl:attribute name="itemspc_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@partnumber"/>
	        </xsl:attribute>
		  <xsl:attribute name="baseitem_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
			<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@parentpartnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@parentpartnumber"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>
		  <xsl:attribute name="member_id">
	                  <xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
		  <xsl:attribute name="discontinued">
	                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="lastupdate">
			<xsl:if test="@lastupdate!='00000000'">
	                  <xsl:value-of select="@lastupdate "/>
			</xsl:if>
              </xsl:attribute>


		<xsl:copy-of select="@partnumber"/>

     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for creating a itemspc for an item in ITEMSPC ends -->

<!-- Transformation Rules for creating an item in CATENTRY starts -->

<xsl:template name="Create">   
	<xsl:element name="catentry">      
              <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
                  <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@partnumber"/>
              </xsl:attribute>
		   <xsl:attribute name="member_id">
	                  <xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="catenttype_id">
	                  <xsl:value-of select="$CatentryItemType"/>
              </xsl:attribute>
		 <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
		  <xsl:attribute name="buyable">
	                  <xsl:value-of select="$OneValue"/>
              </xsl:attribute>
		  <xsl:attribute name="itemspc_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@partnumber"/>
              </xsl:attribute>
		<xsl:attribute name="lastupdate">
			<xsl:if test="@lastupdate!='00000000'">
	                  <xsl:value-of select="@lastupdate "/>
			</xsl:if>
              </xsl:attribute>

		<xsl:attribute name="partnumber">
				<xsl:value-of select="normalize-space(@partnumber)"/>
		 </xsl:attribute>
		<xsl:attribute name="mfpartnumber">
		 <xsl:choose>
			<xsl:when test="normalize-space(@mfpartnumber)=''">
				<xsl:value-of select="normalize-space(@partnumber)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space(@mfpartnumber)"/>
			</xsl:otherwise>
		 </xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="mfname">
		 <xsl:choose>
			<xsl:when test="normalize-space(@mfname)=''">
				<xsl:value-of select="$DefaultProductMFName"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space(@mfname)"/>
			</xsl:otherwise>
		 </xsl:choose>
		</xsl:attribute>
     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for creating an item in CATENTRY ends -->

<!-- Transformation Rules for creating a product in CATENTRY starts -->

<xsl:template name="CreateParent">   
	<xsl:element name="catentry">
		  <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
               </xsl:attribute>
      	   <xsl:attribute name="member_id">
	                  <xsl:value-of select="$MemberIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="catenttype_id">
	                  <xsl:value-of select="$CatentryProductType"/>
              </xsl:attribute>
		 <xsl:attribute name="markfordelete">
	                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
		 <xsl:attribute name="buyable">
	                  <xsl:value-of select="$OneValue"/>
              </xsl:attribute>
		  <xsl:attribute name="baseitem_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>
		<xsl:attribute name="lastupdate">
			<xsl:if test="@lastupdate!='00000000'">
	                  <xsl:value-of select="@lastupdate "/>
			</xsl:if>
              </xsl:attribute>
		<xsl:attribute name="partnumber">
		  	<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>
		<xsl:attribute name="mfpartnumber">
		 <xsl:choose>
			<xsl:when test="normalize-space(@mfpartnumber)=''">
 				<xsl:value-of select="normalize-space(@partnumber)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space(@mfpartnumber)"/>
			</xsl:otherwise>
		 </xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="mfname">
		 <xsl:choose>
			<xsl:when test="normalize-space(@mfname)=''">
				<xsl:value-of select="$DefaultProductMFName"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space(@mfname)"/>
			</xsl:otherwise>
		 </xsl:choose>
		</xsl:attribute>
	</xsl:element> 
</xsl:template>

<!-- Transformation Rules for creating a product in CATENTRY ends -->

<!-- Transformation Rules for relating a product to a catgroup in CATGPENREL starts -->

<xsl:template name="CreateCatGroupRel">   
	<xsl:element name="catgpenrel">      
              <xsl:attribute name="catgroup_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="$DefaultSubCatgroupIdentifier"/>
              </xsl:attribute>
		   <xsl:attribute name="catalog_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$CatalogName"/>
              </xsl:attribute>
		  <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>

     </xsl:element> 
</xsl:template>

<!-- Transformation Rules for relating a product to a catgroup in CATGPENREL ends -->

<!-- Transformation Rules for create an item in CATENTDESC starts -->

<xsl:template name="Createindesc">   
	<xsl:element name="catentdesc">
		   <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
           		  <xsl:value-of select="$RootPrefix"/>
			        <xsl:value-of select="@catentry_id"/>
        			</xsl:attribute>
			<xsl:attribute name="published">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
			<xsl:attribute name="available">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
			<xsl:attribute name="language_id">
				<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@desclanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@desclanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="shortdescription">
			 <xsl:choose>
				<xsl:when test="normalize-space(@shortdescription)=''">
					<xsl:value-of select="normalize-space(@name)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@shortdescription)"/>
				</xsl:otherwise>
			 </xsl:choose>
			</xsl:attribute>
		<xsl:copy-of select="@name | @longdescription | @fullimage"/>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules for create an item in CATENTDESC ends -->

<!-- Transformation Rules for create a product in CATENTDESC starts -->

<xsl:template name="CreateParentindesc">   
	<xsl:element name="catentdesc">
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@catentry_id)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@catentry_id)"/>
				</xsl:otherwise>
			</xsl:choose>
               </xsl:attribute>
			<xsl:attribute name="published">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
			<xsl:attribute name="available">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
			<xsl:attribute name="language_id">
				<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
			</xsl:attribute>

<!-- When no name or shortdescription is present for parent product then we construct the description
	as Product - <material group partnumber> -->

			<xsl:attribute name="shortdescription">
 			 <xsl:choose>
				<xsl:when test="normalize-space(@shortdescription)=''">
					<xsl:value-of select="$DefaultProductDesc"/>
					<xsl:value-of select="normalize-space(@catentry_id)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@shortdescription)"/>
				</xsl:otherwise>
			 </xsl:choose>
			</xsl:attribute>
			
			<xsl:attribute name="name">
 			 <xsl:choose>
				<xsl:when test="normalize-space(@name)=''">
					<xsl:value-of select="$DefaultProductDesc"/>
					<xsl:value-of select="normalize-space(@catentry_id)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@name)"/>
				</xsl:otherwise>
			 </xsl:choose>
			</xsl:attribute>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules for create a product in CATENTDESC ends -->

<!-- Transformation Rules for create a listing in LISTPRICE starts -->

<xsl:template name="Createinprice">   
	<xsl:element name="listprice">
		              <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
           		  <xsl:value-of select="$RootPrefix"/>
			        <xsl:value-of select="@catentry_id"/>
        			</xsl:attribute>
				<xsl:attribute name="listprice">
			        <xsl:value-of select="normalize-space(@listprice)"/>
        			</xsl:attribute>
				<xsl:attribute name="currency">
		      	  <xsl:value-of select="normalize-space(@currency)"/>
				</xsl:attribute>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules for create a listing in LISTPRICE ends -->

<!-- Transformation Rules for create a listing in CATENTSHIP starts -->

<xsl:template name="Createinship">   
	<xsl:element name="catentship">
		              <xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
           		  <xsl:value-of select="$RootPrefix"/>
			        <xsl:value-of select="@catentry_id"/>
     			</xsl:attribute>
			<xsl:attribute name="nominalquantity">
			<xsl:choose>
				<xsl:when test="normalize-space(@nominalquantity)='0.000'">
					<xsl:value-of select="$OneValue"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@nominalquantity)"/>
				</xsl:otherwise>
			</xsl:choose>
	    		</xsl:attribute>
		<xsl:copy-of select="@quantitymeasure"/>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules for create a listing in CATENTSHIP ends -->

<!-- Transformation Rules for relate a product to item in CATENTREL starts -->

<xsl:template name="Copycatentrel">   
	<xsl:element name="catentrel">
		<xsl:attribute name="catentry_id_child">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	                  <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@catentry_id_child"/>
     	</xsl:attribute>
		<xsl:attribute name="catentry_id_parent">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
				<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@catentry_id_parent)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@catentry_id_parent)"/>
				</xsl:otherwise>
			</xsl:choose>
     		</xsl:attribute>
		<xsl:attribute name="catreltype_id">
	                  <xsl:value-of select="$CatentryRelationType"/>
		</xsl:attribute>


     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules for relate a product to item in CATENTREL ends -->

<!-- Transformation Rules to put in entry in QTYUNIT starts -->

<xsl:template name="Copyqtyunit">   
	<xsl:element name="qtyunit">
		  <xsl:attribute name="field1">
                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
		<xsl:copy-of select="@qtyunit_id"/>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in QTYUNIT ends-->

<!-- Transformation Rules to put in entry in ATTRIBUTE starts -->

<xsl:template name="Copyattr">   
	<xsl:element name="attribute">
		<xsl:attribute name="attribute_id">
	                  <xsl:value-of select="$RootPrefix"/>
     	            <xsl:choose>
				<xsl:when test="normalize-space(@catentry_id)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@catentry_id)"/>
				</xsl:otherwise>
			</xsl:choose>

				<xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@name"/>
				<xsl:value-of select="$RootPrefix"/>
			  <xsl:choose>
				<xsl:when test="normalize-space(@attrlanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>

           </xsl:attribute>
		<xsl:attribute name="language_id">
	<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@attrlanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrlanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="attrtype_id">
			<xsl:value-of select="$attrtypeid"/>
		</xsl:attribute>
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
 	    	</xsl:attribute>
	<xsl:copy-of select="@name"/>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in ATTRIBUTE ends -->

<!-- Transformation Rules to put in entry in ATTRVALUE starts -->

<xsl:template name="Copyattrval">   
	<xsl:element name="attrvalue">
		<xsl:attribute name="attrvalue_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="normalize-space(@partnumber)"/>
			<xsl:value-of select="$RootPrefix"/>
	            <xsl:value-of select="normalize-space(@attribute_id)"/>
			<xsl:value-of select="$RootPrefix"/>  
			  <xsl:choose>
				<xsl:when test="normalize-space(@attrvallanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="attrtype_id">
			<xsl:value-of select="$attrtypeid"/>
		</xsl:attribute>
		<xsl:attribute name="language_id">
	<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(@attrvallanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="name">
			<xsl:value-of select="normalize-space(@attribute_id)"/>
		</xsl:attribute>

		<xsl:attribute name="attribute_id">
	                  <xsl:value-of select="$RootPrefix"/>
     	            <xsl:choose>
				<xsl:when test="normalize-space(@catentry_id_parent)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@catentry_id_parent)"/>
				</xsl:otherwise>
			</xsl:choose>

				<xsl:value-of select="$RootPrefix"/>
		            <xsl:value-of select="@attribute_id"/>
				<xsl:value-of select="$RootPrefix"/>  
			  <xsl:choose>
				<xsl:when test="normalize-space(@attrvallanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@attrvallanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
     		</xsl:attribute>
     			<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
                  <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="normalize-space(@partnumber)"/>
     	</xsl:attribute>

		<xsl:copy-of select="@stringvalue"/>

     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in ATTRVALUE ends -->

<!-- Transformation Rules to put in entry in OFFER starts -->

<xsl:template name="Copyoffer">   
	<xsl:element name="offer">
		<xsl:attribute name="offer_id">
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="@catentry_id"/>
		</xsl:attribute>
		<xsl:attribute name="tradeposcn_id">
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="$MemberIdentifier"/>
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="$TradingPositionName"/>
		</xsl:attribute>
		<xsl:attribute name="published">
	            <xsl:value-of select="$OneValue"/>
     		</xsl:attribute>
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  <xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:value-of select="@catentry_id"/>
     		</xsl:attribute>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in OFFER ends -->

<!-- Transformation Rules to put in entry in OFFERPRICE starts -->

<xsl:template name="Copyofferprice">   
	<xsl:element name="offerprice">
		<xsl:attribute name="offer_id">
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="@offer_id"/>
		</xsl:attribute>
		<xsl:attribute name="price">
		        <xsl:value-of select="normalize-space(@price)"/>
		</xsl:attribute>
		<xsl:attribute name="currency">
		        <xsl:value-of select="normalize-space(@currency)"/>
		</xsl:attribute>

	
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in OFFERPRICE ends -->

<!-- Transformation Rules to put in entry in INVENTORY starts -->

<xsl:template name="Copyinventory">
	<xsl:element name="inventory">
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="$MemberIdentifier"/>
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="@catentry_id"/>
		</xsl:attribute>
	
		<xsl:attribute name="quantity">
                  <xsl:value-of select="$OneValue"/>
		</xsl:attribute>
		<xsl:attribute name="ffmcenter_id">
			<xsl:value-of select="$RootPrefix"/>
     	      	<xsl:value-of select="$MemberIdentifier"/>
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$FullFillmentCenterName"/>
		</xsl:attribute>
		<xsl:attribute name="store_id">
                  <xsl:value-of select="$StoreIdentifier"/>
		</xsl:attribute>
		<xsl:attribute name="inventoryflags">
                  <xsl:value-of select="$ZeroValue"/>
		</xsl:attribute>
		<xsl:copy-of select="@quantitymeasure"/>
		
     </xsl:element> 
 
                                                                                  
</xsl:template>

<!-- Transformation Rules to put in entry in INVENTORY ends -->

<!-- Transformation Rules to put in entry in STOREITEM starts -->

<xsl:template name="Copystoreitem">   
	<xsl:element name="storeitem">
		<xsl:attribute name="baseitem_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$MemberIdentifier"/>
	            <xsl:value-of select="$RootPrefix"/>
     	            <xsl:choose>
				<xsl:when test="normalize-space(@partnumber)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@partnumber)"/>
				</xsl:otherwise>
			</xsl:choose>
              </xsl:attribute>
		  <xsl:attribute name="storeent_id">
                  <xsl:value-of select="$StoreIdentifier"/>
              </xsl:attribute>
		  <xsl:attribute name="trackinventory">
                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="forcebackorder">
                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="releaseseparately">
                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="returnnotdesired">
                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="backorderable">
                  <xsl:value-of select="$FalseFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="creditable">
                  <xsl:value-of select="$TrueFlag"/>
              </xsl:attribute>
		  <xsl:attribute name="minqtyforsplit">
                  <xsl:value-of select="$ZeroValue"/>
              </xsl:attribute>
     </xsl:element>                                                                                   
</xsl:template>

<!-- Transformation Rules to put in entry in STOREITEM ends -->

</xsl:stylesheet>
